pub trait DynSignatureAlgorithmIdentifier {
// Required method
fn signature_algorithm_identifier(&self) -> Result<AlgorithmIdentifierOwned>;
}Expand description
Returns AlgorithmIdentifierOwned associated with the signature system.
Unlike AssociatedAlgorithmIdentifier this is intended to be implemented for public and/or
private keys.
Required Methods
Sourcefn signature_algorithm_identifier(&self) -> Result<AlgorithmIdentifierOwned>
fn signature_algorithm_identifier(&self) -> Result<AlgorithmIdentifierOwned>
AlgorithmIdentifier for the corresponding signature system.
Errors
Returns errors specific to the concrete type which impls this trait.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl<T> DynSignatureAlgorithmIdentifier for Twhere
T: SignatureAlgorithmIdentifier,
Available on crate feature
alloc only.